@@ -1,10 +1,13 @@
 """Base objects to be exported for use in Controllers"""
+# Import pkg_resources first so namespace handling is properly done so the
+# paste imports work
+import pkg_resources
+
 from paste.registry import StackedObjectProxy
 
 from pylons.configuration import config
-from pylons.legacy import c, buffet, g, h, jsonify, Response
 
-__all__ = ['app_globals', 'c', 'cache', 'config', 'g', 'request', 'response',
+__all__ = ['app_globals', 'cache', 'config', 'request', 'response',
            'session', 'tmpl_context', 'url']
 
 def __figure_version():
@@ -29,7 +32,7 @@ cache = StackedObjectProxy(name="cache")
 request = StackedObjectProxy(name="request")
 response = StackedObjectProxy(name="response")
 session = StackedObjectProxy(name="session")
-tmpl_context = StackedObjectProxy(name="tmpl_context")
+tmpl_context = StackedObjectProxy(name="tmpl_context or C")
 url = StackedObjectProxy(name="url")
 
 translator = StackedObjectProxy(name="translator")
