@@ -44,8 +44,7 @@ import sys
 
 import paste.fixture
 import paste.registry
-import paste.deploy.config
-from paste.deploy import loadapp, appconfig
+from paste.deploy import loadapp
 from paste.script.command import Command, BadCommand
 from paste.script.filemaker import FileOp
 from tempita import paste_script_template_renderer
@@ -210,7 +209,7 @@ class ControllerCommand(Command):
             
             file_op.template_vars.update(
                 {'name': controller_name,
-                 'fname': os.path.join(directory, name),
+                 'fname': os.path.join(directory, name).replace('\\', '/'),
                  'tmpl_name': name,
                  'package':base_package,
                  'importstatement': importstatement})
@@ -374,6 +373,64 @@ class RestControllerCommand(Command):
             raise BadCommand('An unknown error occurred. %s' % msg)
 
 
+class RoutesCommand(Command):
+    """Print the applications routes
+
+    The optional CONFIG_FILE argument specifies the config file to use.
+    CONFIG_FILE defaults to 'development.ini'.
+
+    Example::
+
+        $ paster routes my-development.ini
+
+    """
+    summary = __doc__.splitlines()[0]
+    usage = '\n' + __doc__
+
+    min_args = 0
+    max_args = 1
+    group_name = 'pylons'
+
+    parser = Command.standard_parser(simulate=True)
+    parser.add_option('-q',
+                      action='count',
+                      dest='quiet',
+                      default=0,
+                      help=("Do not load logging configuration from the "
+                            "config file"))
+
+    def command(self):
+        """Main command to create a new shell"""
+        self.verbose = 3
+        if len(self.args) == 0:
+            # Assume the .ini file is ./development.ini
+            config_file = 'development.ini'
+            if not os.path.isfile(config_file):
+                raise BadCommand('%sError: CONFIG_FILE not found at: .%s%s\n'
+                                 'Please specify a CONFIG_FILE' % \
+                                 (self.parser.get_usage(), os.path.sep,
+                                  config_file))
+        else:
+            config_file = self.args[0]
+
+        config_name = 'config:%s' % config_file
+        here_dir = os.getcwd()
+
+        if not self.options.quiet:
+            # Configure logging from the config file
+            self.logging_file_config(config_file)
+        
+        # Load the wsgi app first so that everything is initialized right
+        wsgiapp = loadapp(config_name, relative_to=here_dir)
+        test_app = paste.fixture.TestApp(wsgiapp)
+
+        # Query the test app to setup the environment and get the mapper
+        tresponse = test_app.get('/_test_vars')
+        mapper = tresponse.config.get('routes.map')
+        if mapper:
+            print mapper
+
+
 class ShellCommand(Command):
     """Open an interactive shell with the Pylons app loaded
 
@@ -430,17 +487,6 @@ class ShellCommand(Command):
             # Configure logging from the config file
             self.logging_file_config(config_file)
         
-        # XXX: Note, initializing CONFIG here is Legacy support. pylons.config
-        # will automatically be initialized and restored via the registry
-        # restorer along with the other StackedObjectProxys
-        # Load app config into paste.deploy to simulate request config
-        # Setup the Paste CONFIG object, adding app_conf/global_conf for legacy
-        # code
-        conf = appconfig(config_name, relative_to=here_dir)
-        conf.update(dict(app_conf=conf.local_conf,
-                         global_conf=conf.global_conf))
-        paste.deploy.config.CONFIG.push_thread_config(conf)
-
         # Load locals and populate with objects for use in shell
         sys.path.insert(0, here_dir)
 
@@ -481,11 +527,11 @@ class ShellCommand(Command):
         if can_import(helpers_module):
             locs['h'] = sys.modules[helpers_module]
 
-        exec ('from pylons import app_globals, c, config, g, request, '
-              'response, session, tmpl_context, url') in locs
+        exec ('from pylons import app_globals, config, request, response, '
+              'session, tmpl_context, url') in locs
         exec ('from pylons.controllers.util import abort, redirect') in locs
         exec 'from pylons.i18n import _, ungettext, N_' in locs
-        exec 'from pylons.templating import render' in locs
+        locs.pop('__builtins__', None)
         
         # Import all objects from the base module
         __import__(base_module)
