@@ -11,12 +11,13 @@ below.
 Functions available:
 
 :func:`abort`, :func:`forward`, :func:`etag_cache`, 
-:func:`mimetype`, :func:`redirect`, and :func:`redirect_to`
+:func:`mimetype` and :func:`redirect`
 """
 import base64
 import binascii
 import hmac
 import logging
+import re
 try:
     import cPickle as pickle
 except ImportError:
@@ -26,7 +27,6 @@ try:
 except ImportError:
     import sha as sha1
 
-from routes import url_for
 from webob import Request as WebObRequest
 from webob import Response as WebObResponse
 from webob.exc import status_map
@@ -38,6 +38,9 @@ __all__ = ['abort', 'etag_cache', 'redirect', 'redirect_to', 'Request',
 
 log = logging.getLogger(__name__)
 
+IF_NONE_MATCH = re.compile('(?:W/)?(?:"([^"]*)",?\s*)')
+
+
 class Request(WebObRequest):
     """WebOb Request subclass
     
@@ -129,8 +132,6 @@ def etag_cache(key=None):
     
     Otherwise, the ETag header will be added to the response headers.
 
-    Returns ``pylons.response`` for legacy purposes (``pylons.response``
-    should be used directly instead).
     
     Suggested use is within a Controller Action like so:
     
@@ -145,13 +146,14 @@ def etag_cache(key=None):
     
     .. note::
         This works because etag_cache will raise an HTTPNotModified
-        exception if the ETag recieved matches the key provided.
+        exception if the ETag received matches the key provided.
     
     """
-    key = str(key)
+    if_none_matches = IF_NONE_MATCH.findall(
+        pylons.request.environ.get('HTTP_IF_NONE_MATCH', ''))
     response = pylons.response._current_obj()
-    response.headers['ETag'] = key
-    if key in pylons.request.if_none_match:
+    response.headers['ETag'] = '"%s"' % key
+    if str(key) in if_none_matches:
         log.debug("ETag match, returning 304 HTTP Not Modified Response")
         response.headers.pop('Content-Type', None)
         response.headers.pop('Cache-Control', None)
@@ -159,10 +161,6 @@ def etag_cache(key=None):
         raise status_map[304]().exception
     else:
         log.debug("ETag didn't match, returning response object")
-        # NOTE: Returning the proxy rather than the actual repsonse, to
-        # easily trigger a DeprecationWarning in Controller.__call__
-        # when a controller returns the result of etag_cache
-        return pylons.response
 
 
 def forward(wsgi_app):
@@ -208,25 +206,3 @@ def redirect(url, code=302):
     log.debug("Generating %s redirect" % code)
     exc = status_map[code]
     raise exc(location=url).exception
-
-
-def redirect_to(*args, **kargs):
-    """Raises a redirect exception to the URL resolved by Routes'
-    url_for function
-    
-    Optionally, a _code variable may be passed with the status code of
-    the redirect, i.e.::
-
-        redirect_to(controller='home', action='index', _code=303)
-    
-    .. warning::
-
-        This function is deprecated. Pass the result of :func:`url` to
-        :func:`redirect` instead.
-
-    """
-    import warnings
-    warnings.warn('redirect_to is deprecated, use redirect(url(*args, '
-                  '**kwargs)) instead.', DeprecationWarning, 2)
-    code = kargs.pop('_code', 302)
-    return redirect(url_for(*args, **kargs), code)
