@@ -7,7 +7,6 @@ try:
     import webhelpers.html.secure_form as secure_form
 except ImportError:
     import webhelpers.pylonslib.secure_form as secure_form
-    
 
 from pylons.controllers.util import abort, redirect
 from pylons.decorators.util import get_pylons
@@ -50,7 +49,7 @@ def authenticate_form(func, *args, **kwargs):
         abort(403, detail=csrf_detected_message)
 
 
-def https(*redirect_args, **redirect_kwargs):
+def https(url_or_callable=None):
     """Decorator to redirect to the SSL version of a page if not
     currently using HTTPS. Apply this decorator to controller methods
     (actions).
@@ -84,13 +83,6 @@ def https(*redirect_args, **redirect_kwargs):
         def get(self):
             do_secure()
 
-    .. warning::
-
-        Arguments as would be passed to the
-        :func:`url_for`/:func:`redirect_to` functions are
-        deprecated. Explicitly specify the url or a callable returning
-        the url instead.
-
     """
     def wrapper(func, *args, **kwargs):
         """Decorator Wrapper function"""
@@ -101,22 +93,12 @@ def https(*redirect_args, **redirect_kwargs):
             # don't allow POSTs (raises an exception)
             abort(405, headers=[('Allow', 'GET')])
 
-        if redirect_kwargs:
-            # XXX: not a foolproof check for url_for arguments, but the
-            # best we can do
-            import warnings
-            from routes import url_for
-            warnings.warn('Calling https with url_for args is deprecated, use '
-                          'https(lambda: url(*args, **kwargs)) instead',
-                          DeprecationWarning, 2)
-            redirect_kwargs['protocol'] = 'https'
-            url = url_for(*redirect_args, **redirect_kwargs)
-        elif not redirect_args:
+        if url_or_callable is None:
             url = request.url
+        elif callable(url_or_callable):
+            url = url_or_callable()
         else:
-            url = redirect_args[0]
-            if callable(url):
-                url = url()
+            url = url_or_callable
         # Ensure an https scheme, which also needs a host
         parts = urlparse.urlparse(url)
         url = urlparse.urlunparse(('https', parts[1] or request.host) +
