@@ -44,6 +44,9 @@ class LazyString(object):
     def __mod__(self, other):
         return self.eval() % other
 
+    def format(self, other):
+        return self.eval().format(other)
+
 
 def lazify(func):
     """Decorator to return a lazy-evaluated version of the original"""
@@ -152,12 +155,7 @@ def _get_translator(lang, **kwargs):
         conf = kwargs.pop('pylons_config')
     else:
         conf = pylons.config.current_conf()
-    # XXX: root_path is deprecated
-    try:
-        rootdir = conf['pylons.paths']['root']
-    except KeyError:
-        rootdir = conf['pylons.paths'].get('root_path')
-    localedir = os.path.join(rootdir, 'i18n')
+    localedir = os.path.join(conf['pylons.paths']['root'], 'i18n')
     if not isinstance(lang, list):
         lang = [lang]
     try:
