@@ -1,18 +1,18 @@
 from projectname.tests import *
 from sqlalchemy.exceptions import IntegrityError
-from projectname.model.meta import Session, metadata
+from projectname.model.meta import Session, Base
 from projectname.model import Foo
 
 class TestSQLAlchemyController(TestController):
     def setUp(self):
-        metadata.create_all(bind=Session.bind)
+        Base.metadata.create_all(bind=Session.bind)
         f = Foo(id = 1, bar = u"Wabbit")
         Session.add(f)
         Session.commit()
         assert f.bar == u"Wabbit"
     
     def tearDown(self):
-        metadata.drop_all(bind=Session.bind)
+        Base.metadata.drop_all(bind=Session.bind)
 
     def test_sqlalchemy(self):
         response = self.app.get(url(controller='sample', action='testsqlalchemy'))
